package com.example.beginnerwebview;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.swiperefreshlayout.widget.SwipeRefreshLayout;

import android.app.DownloadManager;
import android.graphics.Bitmap;
import android.net.Uri;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.webkit.DownloadListener;
import android.webkit.WebChromeClient;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.ProgressBar;

public class MainActivity extends AppCompatActivity {

    //layout elements:
    SwipeRefreshLayout swipeRefreshLayout;
    LinearLayout outsideLinearLayout,topLinearLayout;
    ImageView iconView;
    ProgressBar progressBar;
    WebView mainWebView;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        //initialize layout elements
        swipeRefreshLayout = findViewById(R.id.swipeRefreshLayout);
        outsideLinearLayout = findViewById(R.id.outsideLinearLayout);
        topLinearLayout = findViewById(R.id.topLinearLayout);
        iconView = findViewById(R.id.iconView);
        progressBar = findViewById(R.id.topProgressBar);
        mainWebView = findViewById(R.id.mainWebView);

        //Refresh the page on swipe up.
        swipeRefreshLayout.setOnRefreshListener(new SwipeRefreshLayout.OnRefreshListener() {
            @Override
            public void onRefresh() {
                mainWebView.reload();
            }
        });

        //Set Progress Bar Maximum
        progressBar.setMax(100);

        //Starting URL
        mainWebView.loadUrl("https://www.google.com/");
        //Enable Javascript
        mainWebView.getSettings().setJavaScriptEnabled(true);
        mainWebView.setWebViewClient(new WebViewClient(){
            @Override
            public void onPageStarted(WebView view, String url, Bitmap favicon) {
                //When the page starts loading.
                topLinearLayout.setVisibility(View.VISIBLE);
                super.onPageStarted(view, url, favicon);
            }

            @Override
            public void onPageFinished(WebView view, String url) {
                //When the page has finished loading.
                topLinearLayout.setVisibility(View.INVISIBLE);
                swipeRefreshLayout.setRefreshing(false);
                super.onPageFinished(view, url);
            }
        });
        mainWebView.setWebChromeClient(new WebChromeClient(){
            @Override
            public void onProgressChanged(WebView view, int newProgress) {
                super.onProgressChanged(view, newProgress);
                //Keep progressBar updated.
                progressBar.setProgress(newProgress);
            }

            @Override
            public void onReceivedTitle(WebView view, String title) {
                super.onReceivedTitle(view, title);
                //Set the page title.
                getSupportActionBar().setTitle(title);
            }

            @Override
            public void onReceivedIcon(WebView view, Bitmap icon) {
                super.onReceivedIcon(view, icon);
                //Change icon to icon of current web page.
                iconView.setImageBitmap(icon);
            }
        });
        //Download manager.
        mainWebView.setDownloadListener(new DownloadListener() {
            @Override
            public void onDownloadStart(String s, String s1, String s2, String s3, long l) {
                //Download Request
                DownloadManager.Request currRequest = new DownloadManager.Request(Uri.parse(s));
                currRequest.allowScanningByMediaScanner();
                currRequest.setNotificationVisibility(DownloadManager.Request.VISIBILITY_VISIBLE_NOTIFY_COMPLETED);

                //Download Manager
                DownloadManager currDownload = (DownloadManager) getSystemService(DOWNLOAD_SERVICE);
                currDownload.enqueue(currRequest);
            }
        });
    }
    @Override
    public void onBackPressed() {
        if(mainWebView.canGoBack()){
            mainWebView.goBack();
        } else {
            super.onBackPressed();
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        MenuInflater menuInflater = getMenuInflater();
        menuInflater.inflate(R.menu.browser_menu, menu);
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(@NonNull MenuItem item) {
        switch(item.getItemId()){
            case R.id.menuRefresh:
                mainWebView.reload();
                break;
            case R.id.menuBack:
                onBackPressed();
                break;
            case R.id.menuForward:
                if(mainWebView.canGoForward())
                    mainWebView.goForward();
                break;
            case R.id.youtubeButton:
                mainWebView.loadUrl("https://www.youtube.com/");
                break;
            case R.id.googleButton:
                mainWebView.loadUrl("https://www.google.com/");
                break;
            case R.id.facebookButton:
                mainWebView.loadUrl("https://www.facebook.com/");
                break;
        }

        return super.onOptionsItemSelected(item);
    }
}
